@@ -17,6 +17,8 @@ BEGIN {
 
 sub load {0}
 
+sub bitness {}
+
 sub identify {
     my $self = shift;
     $self->{META_DATA} ||= [
@@ -67,6 +69,10 @@ See identify in L<Sys::Info::Device::CPU>.
 
 See load in L<Sys::Info::Device::CPU>.
 
+=head2 bitness
+
+See bitness in L<Sys::Info::Device::CPU>.
+
 =head1 SEE ALSO
 
 L<Sys::Info>, L<Sys::Info::CPU>, L<Unix::Processors>.
